@@ -1,6 +1,6 @@
 /*
  *  ydpdict
- *  (c) 1998-2004 wojtek kaniewski <wojtekka@irc.pl>
+ *  (C) Copyright 1998-2005 Wojtek Kaniewski <wojtekka@toxygen.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #define YDP_CANTOPENDEF 2
 #define YDP_INVALIDFILE 3
 
-unsigned long *indexes;	/* tablica z indeksami definicji w pliku indeksowym */
+unsigned int *indexes;	/* tablica z indeksami definicji w pliku indeksowym */
 u_char **words;		/* tablica z list sw */
 unsigned short wordcount;	/* ilo sw */
 FILE *fd, *fi;		/* strumienie */
