@@ -1,7 +1,7 @@
 /*
  *  ydpdict
- *  (c) 1998-2004 wojtek kaniewski <wojtekka@irc.pl>
- *                piotr domagalski <szalik@szalik.net>
+ *  (C) Copyright 1998-2005 Wojtek Kaniewski <wojtekka@toxygen.net>
+ *                          Piotr Domagalski <szalik@szalik.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,6 +40,11 @@
 #define DEFDICT_PA "dict101.dat"
 #define DEFINDEX_PA "dict101.idx"
 
+#define DEFDICT_DP "dict200.dat"
+#define DEFINDEX_DP "dict200.idx"
+#define DEFDICT_PD "dict201.dat"
+#define DEFINDEX_PD "dict201.idx"
+
 #define INPUTLEN 17
 
 /* podstawowe zmienne programu */
@@ -87,8 +92,10 @@ int main(int argc, char **argv)
 
 	/* wczytaj konfiguracj (przed inicjalizacj ncurses) */
 	read_config(argc, argv);
-	if (charset == 3)
-		puts((char *)putchar);
+	if (charset == 3) {
+		puts("\033%G");
+		fflush(stdout);
+	}
 
 	/* inicjalizacja ncurses */
 	initscr();
@@ -131,7 +138,7 @@ int main(int argc, char **argv)
 	preparewins();
 
 	/* zaaduj sownik */
-	change_dict((dict_ap) ? 0 : 1);
+	change_dict(dict);
 
 	init = 0;
 
@@ -277,14 +284,14 @@ int main(int argc, char **argv)
 				break;
 			case KEY_F(2):
 			case '`':
-				if (dict_ap == 1) {
-				    if (playsample(pos + menu) < 1);
-				}
+				if (dict == 0 || dict == 2)
+					if (playsample(pos + menu) < 1);
+
 				break;
 			case KEY_F(1):
 			case '?':
 				def = strdup(_("\
-{\\b ydpdict-" VERSION "\\line\\cf1(c) 1998-2004 by wojtek kaniewski}\
+{\\b ydpdict-" VERSION "\\line\\cf1" HEADER_COPYRIGHT "}\
 \\par\\pard{\
 }\
 {\\line{\\cf2 F1} lub {\\cf2 ?} - pomoc}\
@@ -294,19 +301,21 @@ int main(int argc, char **argv)
 {\\line{\\cf2 F2} lub {\\cf2 `} - odtworzenie wymowy wyrazu}\
 {\\line{\\cf2 F3} lub {\\cf2 <} - sownik angielsko-polski}\
 {\\line{\\cf2 F4} lub {\\cf2 >} - sownik polsko-angielski}\
+{\\line{\\cf2 F5} lub {\\cf2 [} - sownik niemiecko-polski}\
+{\\line{\\cf2 F6} lub {\\cf2 ]} - sownik polsko-niemiecki}\
 {\\line{\\cf2 Ctrl-U} - usunicie wpisywanego sowa}\
 {\\line{\\cf2 Ctrl-L} - odwieenie okna}\
 {\\line{\\cf2 strzaka w lewo} lub {\\cf2 w prawo} - poruszanie si w sowie}\
 {\\line{\\cf2 Enter} - zakoczenie edycji sowa}\
 {\\line{\\cf2 Esc} lub {\\cf2 Ctrl-C} - zakoczenie pracy z programem.}\
 \\par\\pard{\
-kontakt z autorem: {\\b wojtekka@irc.pl} \
-najnowsze wersje s dostpne pod adresem {\\b http://toxygen.net/ydpdict/}\
+Kontakt z autorem: {\\b wojtekka@toxygen.net} \
+Najnowsze wersje s dostpne pod adresem {\\b http://toxygen.net/ydpdict/}\
 }"));
 				break;
 			case KEY_F(3):
 			case '<':
-				if (!dict_ap) {
+				if (dict != 0) {
 					change_dict(0);
 					defline = 0;
 					defupd = 1;
@@ -314,12 +323,28 @@ najnowsze wersje s dostpne pod adresem {\\b http://toxygen.net/ydpdict/}\
 				break;
 			case KEY_F(4):
 			case '>':
-				if (dict_ap) {
+				if (dict != 1) {
 					change_dict(1);
 					defline = 0;
 					defupd = 1;
 				}
 				break;
+			case KEY_F(5):
+			case '[':
+				if (dict != 2) {
+					change_dict(2);
+					defline = 0;
+					defupd = 1;
+				}
+				break;
+			case KEY_F(6):
+			case ']':
+				if (dict != 3) {
+					change_dict(3);
+					defline = 0;
+					defupd = 1;
+				}
+				break;
 			case KEY_UP:
 				if (defmark) {
 					if (defline > 0)
@@ -373,7 +398,7 @@ najnowsze wersje s dostpne pod adresem {\\b http://toxygen.net/ydpdict/}\
 				} else {
 					if (menu < ysize - 5)
 						menu = ysize - 5;
-					else if (pos < wordcount - 39)
+					else if (pos < wordcount - (ysize - 4) * 2 - 1)
 						pos += ysize - 4;
 					else
 						pos = wordcount - (ysize - 4);
@@ -534,10 +559,7 @@ void preparewins()
 	keypad(wordwin, TRUE);
 	halfdelay(100);
 
-	werase(wordwin);
-	werase(defwin);
-	werase(headwin);
-	werase(splitwin);
+	erase();
 
 	/* narysuj cudown pionow lini */
 	for (x = 0; x < ysize; x++) {
@@ -592,7 +614,7 @@ void resize()
 
 void checksize()
 {
-	int newx, newy, fake = 0;
+	int newx, newy, fake = 0, diff;
 
 	newx = stdscr->_maxx + 1;
 	newy = stdscr->_maxy + 1;
@@ -608,6 +630,17 @@ void checksize()
 
 	xsize = newx;
 	ysize = newy;
+
+	diff = pos + (ysize - 4) - wordcount;
+	if (diff > 0) {
+		pos -= diff;
+		menu += diff;
+	}
+	diff = menu - (ysize - 5);
+	if (diff > 0) {
+		pos += diff;
+		menu -= diff;
+	}
 }
 
 /* czy podany znaczek da si wywietli i wprowadzi z klawiatury? */
@@ -822,12 +855,16 @@ void showmenu(int pos, int menu) {
 	for (y = 0; y < (ysize - 4); y++) {
 		wattrset(wordwin, y == menu ? A_REVERSE : A_NORMAL);
 		mvwprintw(wordwin, y + 1, 0, "                    ");
-		mvwprintw(wordwin, y + 1, 1, convert_plain(strncpy(buf, words[pos + y], sizeof(buf) - 1), charset, 0));
+
+		if (pos + y >= wordcount)
+			continue;
+
+		mvwprintw(wordwin, y + 1, 1, "%s", convert_plain(strncpy(buf, words[pos + y], sizeof(buf) - 1), charset, 0));
 	}
 	
 	wattrset(wordwin, exact ? A_BOLD : A_NORMAL);
 	mvwprintw(wordwin, 0, 0, "[__________________]");
-	mvwprintw(wordwin, 0, 1, convert_plain(strncpy(buf, input, sizeof(buf) - 1), charset, 0));
+	mvwprintw(wordwin, 0, 1, "%s", convert_plain(strncpy(buf, input, sizeof(buf) - 1), charset, 0));
 	wattrset(wordwin, A_NORMAL);
 
 	wmove(wordwin, 0, menux + 1);
@@ -853,8 +890,10 @@ void showerror(const u_char *msg)
 	if (msg)
 		fprintf(stderr, "%s\n\n", msg);
 
-	if (charset == 3)
-		puts((char *)putchar);
+	if (charset == 3) {
+		puts("\033%@");
+		fflush(stdout);
+	}
 
 	exit(msg ? 1 : 0);
 }
@@ -867,8 +906,10 @@ void sigsegv()
 }
 
 /* wybiera sownik */
-void change_dict(int pl)
+void change_dict(int new_dict)
 {
+	const char *idx, *dat;
+
 	if (!init)
 		closedict();
 
@@ -879,7 +920,29 @@ void change_dict(int pl)
 
 	updateall();
 
-	if (!opendict(filespath, ((pl) ? DEFINDEX_PA : DEFINDEX_AP), ((pl) ? DEFDICT_PA : DEFDICT_AP))) {
+	switch (new_dict) {
+		case 0:
+			idx = DEFINDEX_AP;
+			dat = DEFDICT_AP;
+			break;
+		case 1:
+			idx = DEFINDEX_PA;
+			dat = DEFDICT_PA;
+			break;
+		case 2:
+			idx = DEFINDEX_DP;
+			dat = DEFDICT_DP;
+			break;
+		case 3:
+			idx = DEFINDEX_PD;
+			dat = DEFDICT_PD;
+			break;
+		default:
+			idx = "";
+			dat = "";
+	}
+
+	if (!opendict(filespath, idx, dat)) {
 		switch (ydperror) {
 			case YDP_CANTOPENIDX:
 				showerror(_("Nie mona otworzy pliku indeksowego."));
@@ -890,7 +953,7 @@ void change_dict(int pl)
 		}
 	}
 
-	dict_ap = !pl;
+	dict = new_dict;
 	defline = 0;
 	defupd = 1;
 	menu = 0;
